summaryrefslogtreecommitdiffstats
path: root/src/bin/dhcp4/dhcp4_srv.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/bin/dhcp4/dhcp4_srv.cc')
-rw-r--r--src/bin/dhcp4/dhcp4_srv.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/bin/dhcp4/dhcp4_srv.cc b/src/bin/dhcp4/dhcp4_srv.cc
index 71c385b963..612e8aa58b 100644
--- a/src/bin/dhcp4/dhcp4_srv.cc
+++ b/src/bin/dhcp4/dhcp4_srv.cc
@@ -1020,7 +1020,7 @@ Dhcpv4Srv::run() {
while (!shutdown_) {
#endif // ENABLE_AFL
try {
- run_one();
+ runOne();
getIOService()->poll();
} catch (const std::exception& e) {
// General catch-all exception that are not caught by more specific
@@ -1045,7 +1045,7 @@ Dhcpv4Srv::run() {
}
void
-Dhcpv4Srv::run_one() {
+Dhcpv4Srv::runOne() {
// client's message and server's response
Pkt4Ptr query;
@@ -1176,7 +1176,7 @@ Dhcpv4Srv::processPacket(Pkt4Ptr& query, Pkt4Ptr& rsp, bool allow_packet_park) {
*callout_handle);
// Callouts decided to drop the received packet.
// The response (rsp) is null so the caller (run_one) will
// immediately return too.
if (callout_handle->getStatus() == CalloutHandle::NEXT_STEP_DROP) {
LOG_DEBUG(hooks_logger, DBGLVL_PKT_HANDLING,
@@ -1176,7 +1176,7 @@ Dhcpv4Srv::processPacket(Pkt4Ptr& query, Pkt4Ptr& rsp, bool allow_packet_park) {
*callout_handle);
// Callouts decided to drop the received packet.
- // The response (rsp) is null so the caller (run_one) will
+ // The response (rsp) is null so the caller (runOne) will
// immediately return too.
if (callout_handle->getStatus() == CalloutHandle::NEXT_STEP_DROP) {